==> nextcloud-24.0.9.tgz: nextcloud/apps/notifications/l10n/el.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Γεια σας 1%s",
    "Hello %s," : "Γεια σας 1%s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["Νέα ειδοποίηση για %s","%n νέες ειδοποιήσεις για %s "],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Έχετε μια νέα ειδοποίηση για %s","Έχετε %n νέες ειδοποιήσεις για %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Μπορείτε να αλλάξετε τη συχνότητα αυτών των email ή να τα απενεργοποιήσετε στις <a href=\"%s\"> ρυθμίσεις </a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Μπορείτε να αλλάξετε τη συχνότητα αυτών των email ή να τα απενεργοποιήσετε στις ρυθμίσεις: 1%s",
    "Admin notifications" : "Ειδοποιήσεις διαχειριστή",
    "Notifications" : "Ειδοποιήσεις",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Εφαρμογή ειδοποιήσεων API για  backend και frontend διαθέσιμο στο Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Εφαρμογή ειδοποιήσεων API για backend και frontend διαθέσιμο στο Nextcloud.\n\t\tΤο API χρησιμοποιείται από άλλες εφαρμογές για παροχή ειδοποιήσεων στον χρήστη σχετικά με διάφορα θέματα. Κάποια παραδείγματα είναι:\n\n📬 Federated κοινόχρηστα: Με τη λήψη νέου κοινόχρηστου\n\n📑 Σχόλια: Όταν κάποιος χρήστης αναφέρει το όνομά σας σε κάποιο αρχείο\n\n🚢  Ειδοποίηση αναβάθμισης: Όταν είναι διαθέσιμη αναβάθμιση εφαρμογής ή του nextcloud\n\n📣  Ανακοινώσεις: Δημοσίευση ανακοίνωσης από τον διαχειριστή",
    "Failed to perform action" : "Αποτυχία εκτέλεσης ενέργειας",
    "Dismiss" : "Αποδέσμευση",
    "seconds ago" : " δευτερόλεπτα πριν ",
    "Failed to dismiss notification" : "Αποτυχία αποδέσμευσης της ειδοποίησης",
    "in {path}" : "στο {path}",
    "Dismiss all notifications" : "Εκκαθάριση όλων των ειδοποιήσεων",
    "Requesting browser permissions to show notifications" : "Αίτηση άδειας φυλλομετρητή για εμφάνιση ειδοποιήσεων",
    "No notifications" : "Καμία ειδοποίηση",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Η Nextcloud GmbH χορηγεί μια δωρεάν πύλη ειδοποιήσεων push για ιδιώτες χρήστες. Για να διασφαλιστεί η καλή εξυπηρέτηση, η πύλη περιορίζει τον αριθμό των ειδοποιήσεων push ανά διακομιστή. Για εταιρικούς χρήστες, είναι διαθέσιμη μια πιο επεκτάσιμη πύλη. Επικοινωνήστε με την Nextcloud GmbH για περισσότερες πληροφορίες.",
    "Failed to dismiss all notifications" : "Αποτυχία αποδέσμευσης όλων των ειδοποιήσεων",
    "Send email reminders about unhandled notifications after:" : "Αποστολή υπενθυμίσεων μέσω email για μη χειριζόμενες ειδοποιήσεις μετά από:",
    "Play sound when a new notification arrives" : "Αναπαραγωγή ήχου όταν φτάσει μια νέα ειδοποίηση",
    "Play sound when a call started (requires Nextcloud Talk)" : "Αναπαραγωγή ήχου κατά την έναρξη μιας κλήσης (απαιτείται το Nextcloud Talk)",
    "Never" : "Ποτέ",
    "1 hour" : "1 ώρα",
    "3 hours" : "3 ώρες",
    "1 day" : "1 μέρα",
    "1 week" : "1 εβδομάδα",
    "Your settings have been updated." : "Οι ρυθμίσεις σας έχουν ενημερωθεί.",
    "An error occurred while updating your settings." : "Παρουσιάστηκε σφάλμα κατά την ενημέρωση των ρυθμίσεών σας.",
    "You need to set up your email address before you can receive notification emails." : "Πρέπει να ρυθμίσετε τη διεύθυνση email σας για να μπορείτε να λαμβάνετε μηνύματα ηλεκτρονικού ταχυδρομείου ειδοποίησης."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.8.tgz: nextcloud/apps/notifications/l10n/el.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "Γεια σας 1%s",
    "Hello %s," : "Γεια σας 1%s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["Νέα ειδοποίηση για %s","%n νέες ειδοποιήσεις για %s "],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Έχετε μια νέα ειδοποίηση για %s","Έχετε %n νέες ειδοποιήσεις για %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Μπορείτε να αλλάξετε τη συχνότητα αυτών των email ή να τα απενεργοποιήσετε στις <a href=\"%s\"> ρυθμίσεις </a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Μπορείτε να αλλάξετε τη συχνότητα αυτών των email ή να τα απενεργοποιήσετε στις ρυθμίσεις: 1%s",
    "Admin notifications" : "Ειδοποιήσεις διαχειριστή",
    "Notifications" : "Ειδοποιήσεις",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Εφαρμογή ειδοποιήσεων API για  backend και frontend διαθέσιμο στο Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Εφαρμογή ειδοποιήσεων API για backend και frontend διαθέσιμο στο Nextcloud.\n\t\tΤο API χρησιμοποιείται από άλλες εφαρμογές για παροχή ειδοποιήσεων στον χρήστη σχετικά με διάφορα θέματα. Κάποια παραδείγματα είναι:\n\n📬 Federated κοινόχρηστα: Με τη λήψη νέου κοινόχρηστου\n\n📑 Σχόλια: Όταν κάποιος χρήστης αναφέρει το όνομά σας σε κάποιο αρχείο\n\n🚢  Ειδοποίηση αναβάθμισης: Όταν είναι διαθέσιμη αναβάθμιση εφαρμογής ή του nextcloud\n\n📣  Ανακοινώσεις: Δημοσίευση ανακοίνωσης από τον διαχειριστή",
    "Failed to perform action" : "Αποτυχία εκτέλεσης ενέργειας",
    "Dismiss" : "Αποδέσμευση",
    "Contact Nextcloud GmbH" : "Επικοινωνία με Nextcloud GmbH",
    "seconds ago" : " δευτερόλεπτα πριν ",
    "Failed to dismiss notification" : "Αποτυχία αποδέσμευσης της ειδοποίησης",
    "in {path}" : "στο {path}",
    "Dismiss all notifications" : "Εκκαθάριση όλων των ειδοποιήσεων",
    "Requesting browser permissions to show notifications" : "Αίτηση άδειας φυλλομετρητή για εμφάνιση ειδοποιήσεων",
    "Push notifications might be unreliable" : "Οι ειδοποιήσεις push μπορεί να είναι αναξιόπιστες",
    "No notifications" : "Καμία ειδοποίηση",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Η Nextcloud GmbH χορηγεί μια δωρεάν πύλη ειδοποιήσεων push για ιδιώτες χρήστες. Για να διασφαλιστεί η καλή εξυπηρέτηση, η πύλη περιορίζει τον αριθμό των ειδοποιήσεων push ανά διακομιστή. Για εταιρικούς χρήστες, είναι διαθέσιμη μια πιο επεκτάσιμη πύλη. Επικοινωνήστε με την Nextcloud GmbH για περισσότερες πληροφορίες.",
    "Failed to dismiss all notifications" : "Αποτυχία αποδέσμευσης όλων των ειδοποιήσεων",
    "Notifications defaults" : "Προεπιλογές ειδοποιήσεων",
    "Configure the default notification settings for new users" : "Καθορίστε τις προεπιλεγμένες ρυθμίσεις ειδοποιήσεων για νέους χρήστες.",
    "Send email reminders about unhandled notifications after:" : "Αποστολή υπενθυμίσεων μέσω email για μη χειριζόμενες ειδοποιήσεις μετά από:",
    "Play sound when a new notification arrives" : "Αναπαραγωγή ήχου όταν φτάσει μια νέα ειδοποίηση",
    "Play sound when a call started (requires Nextcloud Talk)" : "Αναπαραγωγή ήχου κατά την έναρξη μιας κλήσης (απαιτείται το Nextcloud Talk)",
    "Never" : "Ποτέ",
    "1 hour" : "1 ώρα",
    "3 hours" : "3 ώρες",
    "1 day" : "1 μέρα",
    "1 week" : "1 εβδομάδα",
    "Your settings have been updated." : "Οι ρυθμίσεις σας έχουν ενημερωθεί.",
    "An error occurred while updating your settings." : "Παρουσιάστηκε σφάλμα κατά την ενημέρωση των ρυθμίσεών σας.",
    "You need to set up your email address before you can receive notification emails." : "Πρέπει να ρυθμίσετε τη διεύθυνση email σας για να μπορείτε να λαμβάνετε μηνύματα ηλεκτρονικού ταχυδρομείου ειδοποίησης."
},
"nplurals=2; plural=(n != 1);");
